function [M, H] = read_timing_749 (path, string, side, style, srv, cli, irt, reply_size, team) 
%   READ_TIMING_749 (path, string, side, style, srv, cli, irt, size, team) 
%   returns a matrix with the timing information from the 
%   corresponding file. 
%
%   [M, H] = read_timing (path, string, side, style, srv, cli, irt, team)
%   returns in M the timing information form all the clients from the 
%   corresponding experiment (each column in the matrix represents one
%   file). H is a cell array containig the host names that correspond to 
%   the columns of M.
%
%   path    = path to file
%   string  = part of the file name identifying the timer
%             (e.g., 'out', 'in', 'msg', 'source')
%   side    = 'cli'/'srv'
%   style   = 'ACTIVE'/'WARM_PASSIVE'
%   srv     = number of server replicas
%   cli     = number of clients
%   irt     = inter-request time
%   reply_size = size of the reply
%   team    = team number (1 to 7)

%   $Date: 2006/4/28 $


% Generic parts of the file name
prefix   = 'DATA749';

% % Parts of the file name that characterize probe #1
% string   = 'app_out';
% side     = 'cli';
% style    = 'WARM_PASSIVE';  % depends on the configuration
% srv      = 2;
% cli      = 1;               % depends on the configuration
% irt      = 0;               % depends on the configuration
% reply_size = 256;           % depends on the configuration
% host     = 'chess';         % depends on the configuration
% team     = 1;               % depends on the team

% Corrections for file names across different teams
if (team==3 || team==5 || team==6 || team==7) irt = irt/1000; end
if (team==4 && strcmp(side, 'srv') && strcmp(string, 'out') && ...
        cli==10 && irt == 40000) irt = irt/1000; end
if (team==3 && reply_size == 0) reply_size = 16; end
if (team==5 && reply_size == 0) reply_size = 4; end
if (team==7 && reply_size == 0) reply_size = 4; end
if (team==2) reply_size = reply_size/2; end

if (team==6 && strcmp(side,'cli'))
    if (strcmp(string,'out')) 
        string = 'in';
    elseif (strcmp(string,'in'))
        string = 'out';
    end
end

M=[]; H=[];

% Compose the file name
if (team == 7)
    filename = sprintf ('%s/%s_app_{%s_%s}_%s_%dsrv_{%d}_%dus_{%d}_req_{*}_team%d*.txt', ...
        path, prefix, string, side, style, srv, cli, ...
        reply_size, irt, team);
else
    filename = sprintf ('%s/%s_app_%s_%s_%s_%dsrv_%dcli_%dus_%dreq_*_team%d.txt', ...
        path, prefix, string, side, style, srv, cli, ...
        irt, reply_size, team);
end

% Find file
lst = dir(filename);

% Check for errors
array_size = size(lst, 1);
if (array_size == 0)
    warning ('CANNOT FIND FILENAME %s.', filename);
    return;
elseif (side == 'cli' & array_size ~= cli)
    warning ('FOR %s\n\tFOUND %d CLIENTS.', filename, array_size);
elseif (side == 'srv' & array_size ~= srv)
    %warning ('FOR %s\n\tFOUND %d SERVERS.', filename, array_size);
end
 
% % Sort all matching files by date
% [zz,perm] = sort(datenum({lst(:).date}));
% lst = lst(perm);

% % Read only from the most recent file
% M = load(sprintf('%s/%s', path, lst(array_size).name));
H = {};
if (side == 'cli')
    for i=1:cli,
        M(:,i) = load(sprintf('%s/%s', path, lst(i).name));

        expr = 'req_([a-z]*)_';
        [start, finish] = regexp(lst(i).name, expr, 'once');
        H(i) = cellstr (lst(i).name(start+4:finish-1));    
    end
else 
    if (team == 3)
        % Team 3 recorded the server-side probes in separate files for each
        % client
        [zz,perm] = sort({lst(:).name});
        lst = lst(perm);
        M = [];
        for i=1:array_size,
            M = [M ; load(sprintf('%s/%s', path, lst(i).name))];
            H = cellstr ('');
        end
    else        
        M = load(sprintf('%s/%s', path, lst(1).name));
        
        expr = 'req_([a-z]*)_';
        [start, finish] = regexp(lst(1).name, expr, 'once');
        H = cellstr (lst(1).name(start+4:finish-1));
    end
end

if (~isempty(find(M<0)))
    % Integer overflow when recording timestamp
    if (team == 2)
        % Correct overflow; assume data was represented on a 32-bit int and
        % it could be represented on a 64-bit int
        M(M<0) = 2^32 + M(M<0);
    else
        warning ('TIMER OVERFLOW IN %s', filename);
    end
end

if (team == 3)
    M = 1000 * M;
end